%% Omnidrive
% Write data to Robotino's omnidrive
%% Syntax 
% r = Omnidrive( IPADDRESS, values )
%% Description
% r = Omnidrive( IPADDRESS, values ) writes values to Robotino's drivesystem. r is 1 if values have been written successfully. r is 0 otherwise.
%
% values is an array of
%
% - vx in m/s
%
% - vy in m/s
%
% - omega in rad/s
%% Example Usage 
% vx = 1
%
% vy = 0
%
% omega = 0
%
% r = OmniDrive( '192.168.0.1', [vx,vy,omega] )
%% See also
% <example_matlab_DistanceSensor.html DistanceSensor Example>
%% Code
function [ success ] = OmniDrive( IPADDRESS, values )
url = sprintf('http://%s/data/omnidrive',IPADDRESS);
try
  webwrite(url,values);
  success = 1;
catch ME
  sprintf('Write to %s failed with error %s',url,ME.identifier)
  success = 0;
end
end